<?php

namespace Drupal\hover_card\Controller;

use Drupal\Component\Utility\Html;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\RendererInterface;
use Drupal\user\UserInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;

/**
 * Default controller for the hover_card module.
 */
class DefaultController extends ControllerBase {

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * Constructs a DefaultController object.
   *
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer service.
   */
  public function __construct(RendererInterface $renderer) {
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('renderer')
    );
  }

  /**
   * Returns the user data.
   *
   * @param \Drupal\user\UserInterface $user
   *   The user object.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   The user data.
   *
   * @throws \Exception
   */
  public function hoverCard(UserInterface $user) {
    $name = $mail = $roles = $picture = "";
    $name = $user->getAccountName();

    if ($user->getEmail() && $this->config('hover_card.settings')->get('email_display_status_value')) {
      $mail = $user->getEmail();
    }

    if ($user->id()) {
      if (!$user->get('user_picture')->isEmpty()) {
        $picture = $user->get('user_picture')->view('thumbnail');
      }
    }

    foreach ($user->getRoles() as $value) {
      $roles = $value;
    }

    $user_data = [
      'name' => Html::escape($name),
      'mail' => Html::escape($mail),
      'picture' => $picture,
      'roles' => Html::escape($roles),
    ];

    $hover_card_template_build = [
      '#theme' => 'hover_card_template',
      '#details' => $user_data,
    ];

    $response = new Response();
    $response->setContent($this->renderer->render($hover_card_template_build));
    return $response;
  }

}
